@@ -3,14 +3,16 @@ mod dynamodb;
 mod mysql;
 mod postgres;
 mod redis;
+mod sqlite;
 mod tidb;
 mod tikv;
 
 pub use cassandra::Cassandra;
 pub use dynamodb::DynamoDB;
 pub use mysql::MySQL;
-pub use postgres::PostgreSQL;
+pub use postgres::Postgres;
 pub use redis::Redis;
+pub use sqlite::SQLite;
 pub use tidb::TiDB;
 pub use tikv::TiKV;
 
